@@ -73,13 +73,15 @@ bool FBSDTimeDateCtl::useNtp() const
     QProcess process;
     QStringList args = QStringList();
     args  << QSL("/etc/rc.d/ntpd") << QSL("rcvar");
-    process.start(QSL("/bin/sh"),args);
+    process.start(QSL("/bin/sh"), args);
     process.waitForFinished(-1);
     QString t = QString::fromLatin1(process.readAllStandardOutput());
     QStringList o = t.split(QSL("\n"));
     for (QStringList::iterator it = o.begin(); it != o.end(); ++it) {
         QString current = *it;
-        if(!current.startsWith(QSL("#")) && current.contains(QSL("ntpd_enable"),Qt::CaseInsensitive) && current.contains(QSL("yes"),Qt::CaseInsensitive)) {
+        if(!current.startsWith(QSL("#")) && current.contains(QSL("ntpd_enable"), Qt::CaseInsensitive)
+           && current.contains(QSL("yes"), Qt::CaseInsensitive))
+        {
             return true;
         }
     }
