@@ -150,10 +150,12 @@ void MainWindow::onAdd()
         UserDialog dlg(mUserManager, &newUser, this);
         if(dlg.exec() == QDialog::Accepted)
         {
-            mUserManager->addUser(&newUser);
-            QByteArray newPasswd;
-            if(getNewPassword(newUser.name(), newPasswd)) {
-                mUserManager->changePassword(&newUser, newPasswd);
+            if(mUserManager->addUser(&newUser))
+            {
+                QByteArray newPasswd;
+                if(getNewPassword(newUser.name(), newPasswd)) {
+                    mUserManager->changePassword(&newUser, newPasswd);
+                }
             }
         }
     }
@@ -172,6 +174,9 @@ void MainWindow::onDelete()
 {
     if(ui.tabWidget->currentIndex() == PageUsers)
     {
+        if (ui.userList->selectedItems().isEmpty())
+            return;
+
         QTreeWidgetItem* item = ui.userList->currentItem();
         UserInfo* user = userFromItem(item);
         if(user)
@@ -184,6 +189,9 @@ void MainWindow::onDelete()
     }
     else if(ui.tabWidget->currentIndex() == PageGroups)
     {
+        if (ui.groupList->selectedItems().isEmpty())
+            return;
+
         QTreeWidgetItem* item = ui.groupList->currentItem();
         GroupInfo* group = groupFromItem(item);
         if(group)
@@ -224,6 +232,9 @@ void MainWindow::onChangePasswd() {
     GroupInfo* group = nullptr;
     if(ui.tabWidget->currentIndex() == PageUsers)
     {
+        if (ui.userList->selectedItems().isEmpty())
+            return;
+
         QTreeWidgetItem* item = ui.userList->currentItem();
         user = userFromItem(item);
         if (!user)
@@ -233,6 +244,9 @@ void MainWindow::onChangePasswd() {
     }
     else if(ui.tabWidget->currentIndex() == PageGroups)
     {
+        if (ui.groupList->selectedItems().isEmpty())
+            return;
+
         QTreeWidgetItem* item = ui.groupList->currentItem();
         group = groupFromItem(item);
         if (!group)
@@ -261,6 +275,9 @@ void MainWindow::onEditProperties()
 {
     if(ui.tabWidget->currentIndex() == PageUsers)
     {
+        if (ui.userList->selectedItems().isEmpty())
+            return;
+
         QTreeWidgetItem* item = ui.userList->currentItem();
         UserInfo* user = userFromItem(item);
         if(user) {
@@ -274,6 +291,9 @@ void MainWindow::onEditProperties()
     }
     else if(ui.tabWidget->currentIndex() == PageGroups)
     {
+        if (ui.groupList->selectedItems().isEmpty())
+            return;
+
         QTreeWidgetItem* item = ui.groupList->currentItem();
         GroupInfo* group = groupFromItem(item);
         if(group) {
